==> bluer_sbc-9.222.1.tar.gz: bluer_sbc-9.222.1/bluer_sbc/README/designs/swallow_head/parts.py <==
parts = {
    "sd-card-32-gb": "",
    "rpi": "",
    "XL4015": "",
    "470-mF": "",
    "Polyfuse": "optional",
    "TVS-diode": "",
    "resistor": "7 x 330-470 Ω + 4 x 2.2 kΩ + 4 x 3.3 kΩ",
    "LED": "green + red + yellow + 4 x blue",
    "rpi-camera": "",
    "PCB-single-14x9_5": "2 x",
    "PCB-double-9x7": "2 x",
    "pushbutton": "",
    "ultrasonic-sensor": "4 x",
    "connector": "1 female",
    "nuts-bolts-spacers": " + ".join(
        [
            "M2: ({})".format(
                " + ".join(
                    [
                        "2 x bolt",
                        "4 x nut",
                        "2 x 5 mm spacer",
                    ]
                )
            ),
            "M2.5: ({})".format(
                " + ".join(
                    [
                        "4 x bolt",
                        "4 x nut",
                        "8 x 10 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "1 x bolt",
                        "5 x nut",
                        "3 x 35 mm spacer",
                        "3 x 25 mm spacer",
                        "7 x 15 mm spacer",
                        "4 x 5 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "plexiglass": "14 cm x 9.5 cm",
    "green-terminal": "2 x",
    "dupont-cables": "1 x 30 cm + 1 x 10 cm",
    "16-awg-wire": "40 cm x (red + black/blue)",
    "solid-cable-1-15": "10 cm x (red + black/blue)",
    "strong-thread": "1 m",
    "pin-headers": "1 x (female, 2 x 40) -> 2 x 20 + 2 x (male, 1 x 40) -> 4 x 1 + 2 x 20 + 1 x (male, 2 x 40) -> 2 x 2 x 6",
}

==> bluer_sbc-9.272.1.tar.gz: bluer_sbc-9.272.1/bluer_sbc/README/designs/swallow_head/parts.py <==
parts = {
    "sd-card-32-gb": "",
    "rpi": "",
    "XL4015": "",
    "470-mF": "",
    "Polyfuse": "optional",
    "TVS-diode": "",
    "resistor": "7 x 330-470 Ω + 4 x 2.2 kΩ + 4 x 3.3 kΩ",
    "LED": "green + red + yellow + 4 x blue",
    "rpi-camera": "",
    "PCB-single-14x9_5": "",
    "pushbutton": "",
    "ultrasonic-sensor": "4 x",
    "connector": "1 female",
    "nuts-bolts-spacers": " + ".join(
        [
            "M2: ({})".format(
                " + ".join(
                    [
                        "2 x bolt",
                        "4 x nut",
                        "2 x 5 mm spacer",
                    ]
                )
            ),
            "M2.5: ({})".format(
                " + ".join(
                    [
                        "4 x bolt",
                        "4 x nut",
                        "8 x 10 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "1 x bolt",
                        "5 x nut",
                        "5 x 25 mm spacer",
                        "8 x 15 mm spacer",
                        "4 x 5 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "plexiglass": "14 cm x 9.5 cm",
    "green-terminal": "2 x",
    "dupont-cables": "1 x 30 cm + 1 x 10 cm",
    "16-awg-wire": "40 cm x (red + black/blue)",
    "solid-cable-1-15": "10 cm x (red + black/blue)",
    "strong-thread": "1 m",
    "pin-headers": "1 x (female, 2 x 40) -> 2 x 20 + 2 x (male, 1 x 40) -> 4 x 1 + 2 x 20 + 1 x (male, 2 x 40) -> 2 x 2 x 6",
}
